@@ -15,8 +15,8 @@ use Encode;
 use Try::Tiny;
 
 use Interchange6::Schema::Candy -components =>
-  [qw(Helper::Row::OnColumnChange Helper::Row::SelfResultSet
-      InflateColumn::DateTime TimeStamp)];
+  [qw(Helper::Row::OnColumnChange Helper::Row::ProxyResultSetMethod
+      Helper::Row::SelfResultSet InflateColumn::DateTime TimeStamp)];
 
 =head1 DESCRIPTION
 
@@ -1303,21 +1303,11 @@ sub top_reviews {
 
 =head2 variant_count
 
-Returns the number of variants of this product. If the query was constructed
-using L<Interchange6::Schema::ResultSet::Product/with_variant_count> then
-the cached value will be used rather than running a new query.
+Returns the number of variants of this product.
 
 =cut
 
-sub variant_count {
-    my $self = shift;
-    if ( $self->has_column_loaded('variant_count') ) {
-        return $self->get_column('variant_count');
-    }
-    else {
-        return $self->variants->count;
-    }
-}
+proxy_resultset_method 'variant_count';
 
 =head2 has_variants
 
@@ -1339,25 +1329,18 @@ the cached value will be used rather than running a new query.
 
 =cut
 
+proxy_resultset_method _average_rating => {
+    slot             => 'average_rating',
+    resultset_method => 'with_average_rating',
+};
+
 sub average_rating {
     my ( $self, $precision ) = @_;
-    my $avg;
 
     $precision = 1 unless ( defined $precision && $precision =~ /^\d$/ );
 
-    if ( $self->has_column_loaded('average_rating') ) {
+    my $avg = $self->_average_rating;
 
-        # initial query on Product already included average_rating so use it
-
-        $avg = $self->get_column('average_rating');
-    }
-    else {
-
-        # we need a new query
-
-        $avg = $self->reviews( { public => 1, approved => 1 } )
-          ->get_column('rating')->func('AVG');
-    }
     return defined $avg ? sprintf( "%.*f", $precision, $avg ) : undef;
 }
 
@@ -1457,7 +1440,6 @@ sub quantity_in_stock {
     return $quantity;
 }
 
-
 =head2 delete
 
 Overload delete to force removal of any product reviews. Only parent products should have reviews so in the case of child products no attempt is made to delete reviews.
